-- gitano
--
-- Top level include for gitano
--
-- Copyright 2012 Daniel Silverstone <dsilvers@digital-scurf.org>
--

local util = require 'gitano.util'
local config = require 'gitano.config'
local repository = require 'gitano.repository'
local log = require 'gitano.log'
local command = require 'gitano.command'
local actions = require 'gitano.actions'
local lace = require 'gitano.lace'
local supple = require 'gitano.supple'
local auth = require 'gitano.auth'
local plugins = require 'gitano.plugins'
local i18n = require 'gitano.i18n'

return {
   util = util,
   config = config,
   repository = repository,
   log = log,
   command = command,
   actions = actions,
   lace = lace,
   supple = supple,
   auth = auth,
   plugins = plugins,
   i18n = i18n,
}
